==> haskell-hspec-wai-0.11.1-617-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai
version:              0.11.1
visibility:           public
id:                   hspec-wai-0.11.1-4kZsIiNqtnZAJ9shAH29rm
key:                  hspec-wai-0.11.1-4kZsIiNqtnZAJ9shAH29rm
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  98d3e763e669119d3ae860a43cdd4632
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-wai-0.11.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-wai-0.11.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-wai-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai
hs-libraries:         HShspec-wai-0.11.1-4kZsIiNqtnZAJ9shAH29rm
depends:
    QuickCheck-2.15.0.1-3xlJoVjdvgVJR3Okie7O9R base-4.17.2.1
    base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz bytestring-0.11.5.3
    case-insensitive-1.2.1.0-AMgBCf5fDYf4pbGdLaLtss
    hspec-core-2.11.3-KToM2sEQ4LuYVtk4ttUtN
    hspec-expectations-0.8.3-9owhYf9ToO0B0euxB6JgrB
    http-types-0.12.4-8EgajALSM5xB8GFkN9ClFd text-2.0.2
    transformers-0.5.6.2 wai-3.2.4-6pK67aQEgpK6NKWKR3cfH5
    wai-extra-3.1.18-KpHf8AUlYLPIEFgZyWs1rJ

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-0.11.1-618-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-wai
version:              0.11.1
visibility:           public
id:                   hspec-wai-0.11.1-Yp2StFWx1O5Mqx27BUrfg
key:                  hspec-wai-0.11.1-Yp2StFWx1O5Mqx27BUrfg
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  c56ece8a8f48b0ebe435f1e2437a28bf
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-wai-0.11.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-wai-0.11.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-wai-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai
hs-libraries:         HShspec-wai-0.11.1-Yp2StFWx1O5Mqx27BUrfg
depends:
    QuickCheck-2.15.0.1-K2FdhpAloErGP21S0B8fgw base-4.17.2.1
    base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz bytestring-0.11.5.3
    case-insensitive-1.2.1.0-rTys5srD4l50KQCiQKWYt
    hspec-core-2.11.3-IjEZPeANC575vr9jH9oAZe
    hspec-expectations-0.8.3-LrMpsCa55zWGlw5k4mSqLh
    http-types-0.12.4-8KsSLLTB3zVcsjL7f3kez text-2.0.2
    transformers-0.5.6.2 wai-3.2.4-IDOjyIeGcOSAX1FlCquc7y
    wai-extra-3.1.18-8UERkDsigqS8xVFGaK5QEN

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
